@@ -23,8 +23,13 @@
 
 #include <glib.h>
 #include <pwd.h>
+#include <errno.h>
 
-#include "gdm-common-unknown-origin.h"
+#define        VE_IGNORE_EINTR(expr) \
+        do {                         \
+                errno = 0;           \
+                expr;                \
+        } while G_UNLIKELY (errno == EINTR);
 
 #define GDM_CUSTOM_SESSION  "custom"
 
