@@ -358,11 +358,6 @@ gdm_smartcard_manager_init (GdmSmartcardManager *manager)
                                        g_str_equal,
                                        (GDestroyNotify) g_free,
                                        (GDestroyNotify) g_object_unref);
-
-        if (!g_thread_supported()) {
-                g_thread_init (NULL);
-        }
-
 }
 
 static void
@@ -1378,9 +1373,9 @@ gdm_smartcard_manager_create_worker (GdmSmartcardManager  *manager,
                                                    read_fd,
                                                    module);
 
-        worker->thread = g_thread_create ((GThreadFunc)
-                                          gdm_smartcard_manager_worker_run,
-                                          worker, FALSE, NULL);
+        worker->thread = g_thread_new ("smartcard",
+				       (GThreadFunc) gdm_smartcard_manager_worker_run,
+				       worker);
 
         if (worker->thread == NULL) {
                 gdm_smartcard_manager_worker_free (worker);
@@ -1448,8 +1443,6 @@ main (int   argc,
         g_log_set_always_fatal (G_LOG_LEVEL_ERROR
                                 | G_LOG_LEVEL_CRITICAL | G_LOG_LEVEL_WARNING);
 
-        g_type_init ();
-
         g_message ("creating instance of 'smartcard manager' object...");
         manager = gdm_smartcard_manager_new (NULL);
         g_message ("'smartcard manager' object created successfully");
